@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -88,7 +88,9 @@ sub parse_xml ($list, $map) {
 
     my $variable = sub  ($t, $elt) {
         return $condition_variable->($t, $elt) if $elt->first_child_text('term') =~ /^C<Condition/;
-        my $desc = $elt->first_child('listitem')->text;
+
+        my @para_text = map {$_->text} $elt->first_child('listitem')->children('para');
+        my $desc = join("\n\n", @para_text);
 
         # detect deprecated param and what replaces them
         my @supersedes ;
@@ -104,6 +106,9 @@ sub parse_xml ($list, $map) {
         # detect verbatim parts setup with programlisting tag
         $desc =~ s/^\+-\+/    /gm;
 
+        # no need to have more than 2 \n to separate paragraphs
+        $desc =~ s/\n{3,}/\n\n/g;
+
         foreach my $term_elt ($elt->children('term')) {
             my $varname = $term_elt->first_child('varname')->text;
             my ($name, $extra_info) = $varname =~ /C<([\w-]+)=([^>]*)>/ ;
@@ -158,6 +163,19 @@ sub parse_xml ($list, $map) {
     return \%data;
 }
 
+sub check_for_list ($element, $description) {
+    my $is_list = 0;
+    $is_list ||= $element =~ /^(Exec|Condition)/ ;
+    # Requires list and its siblings parameters. See systemd.unit
+    $is_list ||= $element =~ /^(Requires|Requisite|Wants|BindsTo|PartOf|Conflicts)$/ ;
+    # see systemd.resource-control
+    $is_list ||= $element =~ /^(DeviceAllow)$/ ;
+    # see systemd.socket
+    $is_list ||= $element =~ /^Listen/ ;
+    $is_list ||= $description =~ /may be (specified|used) more than once/i ;
+
+    return $is_list ? qw/type=list cargo/ : () ;
+}
 
 sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info, $supersedes) {
 
@@ -204,9 +222,7 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info, $sup
         push @load_extra , q!match="^\d+(?i)[KMG]$"!;
     }
 
-    if ($element =~ /^(Exec|Condition)/ or $desc =~ /may be specified more than once/) {
-        push @load, qw/type=list cargo/;
-    }
+    push @load, check_for_list($element, $desc);
 
     push @load, 'type=leaf', "value_type=$value_type";
 
@@ -290,12 +306,13 @@ say "Creating systemd model...";
 
 foreach my $config_class (keys $data->{class}->%*) {
     my $desc_ref = $data->{class}{$config_class};
-    my $desc_text = join("\n\n",$desc_ref->@*);
-    $desc_text =~ s/^\s+//gm;
-    $desc_text =~ s/C<([A-Z]\w+)=>/C<$1>/g;
+
+    # cleanup leading white space and add formatting
+    my $desc_text = join("\n\n", map { s/\n[\t ]+/\n/g; s/C<([A-Z]\w+)=>/C<$1>/g; $_;} $desc_ref->@*);
 
     $desc_text.="\nThis configuration class was generated from systemd documentation.\n"
         ."by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>\n";
+
     my $steps = "class:$config_class class_description";
     $meta_root->grab(step => $steps, autoadd => 1)->store($desc_text);
 
@@ -307,7 +324,6 @@ foreach my $config_class (keys $data->{class}->%*) {
         qq!license="LGPLv2.1+"!,
         qq!accept:".*" type=leaf value_type=uniline warn="Unknown parameter"!,
     ]);
-
 }
 
 foreach my $cdata ($data->{element}->@*) {
@@ -321,7 +337,7 @@ foreach my $cdata ($data->{element}->@*) {
 say "Tweaking systemd model...";
 
 $meta_root->load(
-    'class:Systemd::Section::Service
+    'class:Systemd::Section::Service generated_by="parse-man.pl from systemd doc"
      include:=Systemd::Common::ResourceControl,Systemd::Common::Exec,Systemd::Common::Kill'
 );
 
@@ -340,6 +356,7 @@ foreach my $service (@service_list) {
     $meta_root->load(
         qq!
         class:Systemd::$name
+          generated_by="parse-man.pl from systemd doc"
           element:$name
             type=warped_node
             config_class_name=$class
@@ -363,12 +380,17 @@ foreach my $service (@service_list) {
     $meta_root->load(
         qq!
         class:Systemd
+          generated_by="parse-man.pl from systemd doc"
           element:$service
             type=hash
             index_type=string
             cargo
               type=node
-              config_class_name=Systemd::$name - - !
+              config_class_name=Systemd::$name - -
+          read_config:0
+            backend=Systemd
+            auto_create=1 -
+          !
     );
 }
 
